/*
 *  Projektarbeit zur Vorlesung "Datenbanken" von Prof. Dr. Zhou
 *
 *  "Kundenverwaltungsystem fr ein Webhosting-Unternehmen"
 *
 *  NTA FH Isny, WS 2005/2006
 *  David Mayr, 12.Info
 *
 */

#include "HauptFenster.h"



/**
 *	 Konstruktor des Hauptfensters
 */
HauptFenster::HauptFenster() {
	
	// Konstruktor der GUI-Klasse (mit Designer erzeugte Basisklasse) ausfhren
	GUI_HauptFenster::GUI_HauptFenster();
	
	// Grsse initial anpassen
	setGeometry( 0, 0, 1024, 768 );
	
	// Neues Konfigurations-Fenster erzeugen, aber noch nicht anzeigen
	konfiguration = new Konfiguration();
	
	// Konfiguration aus Datei laden
	konfiguration->laden();

	// Konfig-Dialog nur bei ungltigen Daten anzeigen
	if ( !konfiguration->test() ) {
		// zentriert positionieren
		konfiguration->move( pos().x() + width()/2 ,  pos().y() + height()/2 );
		konfiguration->show();
	}

	// Datenbank ffnen
	datenbank = konfiguration->getDB();
	
	// Zuordnungen von benutzerdefinierten Eingabefeldern und deren Eigenschaften
	QSqlPropertyMap* zuordnung  = new QSqlPropertyMap();
	zuordnung->insert( "AnredeCombobox", "anrede" );
	zuordnung->insert( "KundenCombobox", "kunde" );
	zuordnung->insert( "VertragsCombobox", "vertrag" );
	zuordnung->insert( "MailboxCombobox", "mailbox" );
	zuordnung->insert( "DomainCombobox", "domain" );
	zuordnung->insert( "DatenbankCombobox", "datenbank" );
	QSqlPropertyMap::installDefaultMap( zuordnung );
		
	// Tabellen initialisieren
	kunde_init();	
	vertrag_init();	
	rechnung_init();
	benutzer_init();
	mailbox_init();
	domain_init();
	datenbank_init();
	
}



//////////////////////////////////////////////////////////////////////////////



/**
 *	Kundentabelle initialisieren
 */
void HauptFenster::kunde_init() {

	// Abfrage-Cursor initialisieren und an Tabelle binden
	kundenCursor = new KundenCursor();
	tbKunden->setSqlCursor( kundenCursor, true, true );
	tbKunden->refresh();
	
	// Anrede-ComboBox erstellen und in die GroupBox einfgen 
	// (berdecken der vom Designer erstellten ComboBox !)
	anredeCombobox = new AnredeCombobox( gbKunden, "AnredeCombobox" );
	anredeCombobox->setGeometry( 105, 20, 125, 20 );
	
	// Eingabeformular einrichten / Felder mit GUI verbinden
	kundenFormular = new QSqlForm( this );
	kundenFormular->insert( leKNr, 		"id" );
	kundenFormular->insert( anredeCombobox, 	"Anrede" );
	kundenFormular->insert( leKFirma, 	"Firma" );	
	kundenFormular->insert( leKName, 	"Name" );	
	kundenFormular->insert( leKVorname,	"Vorname" );
	kundenFormular->insert( leKStrasse,	"Strasse" );
	kundenFormular->insert( leKHausNr, 	"HausNr" );
	kundenFormular->insert( leKPLZ, 		"PLZ" );
	kundenFormular->insert( leKOrt, 		"Ort" );
	kundenFormular->insert( leKTelefon,	"Telefon" );
	kundenFormular->insert( leKFax, 		"Fax" );
	kundenFormular->insert( leKEmail, 	"Email" );
	kundenFormular->insert( deKErstellt,	"erstelltAm" );

	// Spaltenbreiten anpassen
	for ( int spalte=0; spalte < tbKunden->numCols(); spalte++ ) {
		tbKunden->adjustColumn( spalte );
		tbKunden->setColumnWidth( spalte, tbKunden->columnWidth(spalte)+4 );
	}
	// Sortierung nach Kunden-ID
	tbKunden->setSort( kundenCursor->index("id") );
	// Standard-Werte setzen
	kunde_neu();
}


/**
 *	Neuen Kunden anlegen, Felder leeren (Tab Kunde -> Button Neu)
 */
void HauptFenster::kunde_neu() {

	// Eingabefelder leeren
	leKFirma->setText("");
	leKName->setText("");
	leKVorname->setText("");
	leKStrasse->setText("");
	leKHausNr->setText("");
	leKPLZ->setText("");
	leKOrt->setText("");
	leKTelefon->setText("");
	leKFax->setText("");
	leKEmail->setText("");	
	cbKAnrede->setCurrentItem(0);
	deKErstellt->setDate( QDate::currentDate() );

	// Nchste freie Kunden-Nummer finden
	QSqlQuery abfrage;
	abfrage.exec( "SELECT MAX(Kunde.id)+1 FROM Kunde;" );
	if ( abfrage.isActive() && abfrage.next() ) {
		leKNr->setText( abfrage.value(0).toString() );
	} else {
		leKNr->setText("");
	}
	anredeCombobox->setFocus();
	tbKunden->refresh();
}


/**
 *	Kunde wurde in Tabelle angeklickt
 */
void HauptFenster::kunde_laden() {
	
	kundenFormular->setRecord( kundenCursor->primeUpdate() );
    kundenFormular->readFields();
    
    QSqlQuery abfrage;
    
	// Vertragslistbox neu erstellen: Alle Vertrge des gewhlten Kunden zeigen ...
	lbKVertraege->clear();
	abfrage.exec( "SELECT  Vertrag.id, Vertrag.Datum  FROM  Vertrag  WHERE  Vertrag.Kunde='"+ leKNr->text() +"';" );
	if ( abfrage.isActive() ) {
		while ( abfrage.next() ) {
			// Listbox fllen
			lbKVertraege->insertItem( 
				"Vertrags-Nr. " + abfrage.value(0).toString() +
				"  vom " + abfrage.value(1).toDate().toString(Qt::LocalDate)
			);
		}
	}
	// Benutzerlistbox neu erstellen: Alle Benutzer des gewhlten Kunden zeigen ...
	lbKBenutzer->clear();
	abfrage.exec( "SELECT  B.Name, B.Speicher  FROM  Benutzer B, Vertrag V  WHERE  B.Vertrag = V.id  AND  V.Kunde = '"+ leKNr->text() +"';" );
	if ( abfrage.isActive() ) {
		while ( abfrage.next() ) {
			// Listbox fllen
			lbKBenutzer->insertItem( 
				abfrage.value(0).toString() + "  (" +
				abfrage.value(1).toString() + " MB)"
			);
		}
	}
	// Rechnungslistbox neu erstellen: Alle Rechnungen des gewhlten Kunden zeigen ...
	lbKRechnungen->clear();
	abfrage.exec( "SELECT  R.id, R.Datum, R.BetragNetto  FROM  Rechnung R, Vertrag V  WHERE  R.Vertrag = V.id  AND  V.Kunde='"+ leKNr->text() +"';" );
	if ( abfrage.isActive() ) {
		while ( abfrage.next() ) {
			// Listbox fllen
			lbKRechnungen->insertItem( 
				"Rechnungs-Nr. " + abfrage.value(0).toString() +
				"  vom " + abfrage.value(1).toDate().toString(Qt::LocalDate)  + 
				" (" + abfrage.value(2).toString() +" EUR)" 
			);
		}
	}
    
}


/**
 *	Kunde speichern (Tab Kunde -> Button Speichern)
 */
void HauptFenster::kunde_speichern() {

	QSqlQuery abfrage;
	abfrage.exec("SELECT MAX(Kunde.id)+1 FROM Kunde;");

	// Vorhandener Kunde -> UPDATE
	if ( abfrage.isActive()  &&  abfrage.next()  &&  ( leKNr->text().toInt() < abfrage.value(0).toInt() ) ) {
    		kundenFormular->setRecord( kundenCursor->primeUpdate() );
    		kundenFormular->writeFields();
    		kundenCursor->update();
		tbKunden->refresh();
		kundenCombobox->zuruecksetzen();
	// Neuer Kunde -> INSERT
	} else {
		deKErstellt->setDate( QDate::currentDate() );
    		kundenFormular->setRecord( kundenCursor->primeInsert() );
    		kundenFormular->writeFields();
		kundenCursor->insert();
		tbKunden->refresh();
		kundenCombobox->zuruecksetzen();		
	}
	
	// Falls Kunde ber Tab "Vertrge" -> Button "Kunde anlegen" gespeichert wurde 
	// -> zurck zum "Vertrge"-Tab und Button zurcksetzen
	if ( pbVKundeNeu->isOn() ) {
		kundenCombobox->setKunde( kundenCursor->primeUpdate()->field("id")->value().toInt() );
		tabs->setCurrentPage( 1 );
		pbVKundeNeu->setOn( false );
	}	
}


/**
 *	Kunde lschen (Tab Kunde -> Button Lschen)
 */
void HauptFenster::kunde_loeschen() {
	
	if ( leKNr->text() != "" ) {

		// Kunde auswhlen
		kundenCursor->select( "id=" + leKNr->text() );
		if ( kundenCursor->next() ) {

			GUI_Sicherheitsabfrage* loeschenDialog = new GUI_Sicherheitsabfrage();
			if ( loeschenDialog->exec() == QDialog::Accepted ) {
				
				// Lsche nachdem Dialog akzeptiert ...
				kundenCursor->primeDelete();
				kundenCursor->del();
				kundenCombobox->zuruecksetzen();
			}
			kunde_neu();
			tbKunden->refresh();
		} else {
			QMessageBox::information( this, "Kunde lschen", "Kunde nicht vorhanden!");
		}
	} else {
		QMessageBox::information( this, "Kunde lschen", "Es wurde kein Kunde ausgewhlt!");
	}
}


/**
 *	Kunde suchen (Tab Kunde -> Button Suchen)
 */
void HauptFenster::kunde_suchen() {
	
	tbKunden->setSort("");
	// Filter (-> WHERE-Statement) setzen
	tbKunden->setFilter( 
		"Name     LIKE '%"+ leKName->text()		+"%' AND "+
		"Firma    LIKE '%"+ leKFirma->text()		+"%' AND "+
		"Vorname  LIKE '%"+ leKVorname->text()	+"%' AND "+
		"Strasse  LIKE '%"+ leKStrasse->text()	+"%' AND "+
		"HausNr   LIKE '%"+ leKHausNr->text()	+"%' AND "+
		"PLZ 	  LIKE '%"+ leKPLZ->text() 		+"%' AND "+
		"Ort 	  LIKE '%"+ leKOrt->text() 		+"%' AND "+
		"Telefon  LIKE '%"+ leKTelefon->text() 	+"%' AND "+
		"Fax 	  LIKE '%"+ leKFax->text() 		+"%' AND "+
		"Email 	  LIKE '%"+ leKEmail->text()		+"%';" );
	// Ergebnis anzeigen
	tbKunden->refresh();
	
	// Filter zurcksetzen - Anzeige aber erst bei nchstem refresh()
	tbKunden->setFilter("");
}



/**
 *	Vertrag mit aktuell gewhltem Kunden anlegen (Tab Kunde -> Button Vertrag anlegen)
 */
void HauptFenster::kunde_VertragNeu() {
	
	// Vertrag mit aktuell gewhltem Kunden anlegen und zu Vertrags-Tab wechseln
	vertrag_neu();
	kundenCombobox->setKunde( kundenCursor->primeUpdate()->field("id")->value().toInt() );
	tabs->setCurrentPage(1);
}



//////////////////////////////////////////////////////////////////////////////



/**
 *	Vertags-tabelle initialisieren
 */
void HauptFenster::vertrag_init() {

	// Abfrage-Cursor initialisieren und an Tabelle binden
	vertragsCursor = new VertragsCursor();
	tbVertraege->setSqlCursor( vertragsCursor, false, true );
	tbVertraege->addColumn( "id", "VNr" );
	tbVertraege->addColumn( "Datum", "Datum" );
	tbVertraege->addColumn( "Kunde", "KNr" );
	tbVertraege->addColumn( "_Kunde", "[Kunde]" );
	tbVertraege->addColumn( "gekndigt", "gekndigt" );
	tbVertraege->addColumn( "gekndigtAm", "Kndigungs-Datum" );
	tbVertraege->addColumn( "_Benutzer", "[Benutzerliste]" );
	tbVertraege->refresh();
	
	// Kunden-ComboBox erstellen und in die GroupBox einfgen 
	// (berdecken der vom Designer erstellten ComboBox !)
	kundenCombobox = new KundenCombobox( gbVertraege, "KundenCombobox" );
	kundenCombobox->setGeometry( 80, 20, 165, 20 );
	
	// Eingabeformular einrichten	
	vertragsFormular = 	new QSqlForm( this );
    vertragsFormular->setRecord( vertragsCursor->primeUpdate() );
	vertragsFormular->insert( leVNr, "id" );
	vertragsFormular->insert( deVDatum, "Datum" );
	vertragsFormular->insert( cbVGekuendigt, "gekndigt" );
	vertragsFormular->insert( deVGekuendigt, "gekndigtAm" );
	vertragsFormular->insert( kundenCombobox, "Kunde" );	
	
	// Spaltenbreiten anpassen
	for ( int spalte=0; spalte < tbVertraege->numCols(); spalte++ ) {
		tbVertraege->adjustColumn( spalte );
		tbVertraege->setColumnWidth( spalte, tbVertraege->columnWidth(spalte)+6 );
	}
	// Sortierung
	tbVertraege->setSort( vertragsCursor->index("id") );
	// Standard-Werte setzen
	vertrag_neu();
}


/**
 *	Neuen Vertrag anlegen, Felder leeren (Tab Vertrag -> Button Neu)
 */
void HauptFenster::vertrag_neu() {

	kundenCombobox->setCurrentItem(0);
	deVDatum->setDate( QDate::currentDate() );
	deVGekuendigt->setDate( QDate( 2000, 01, 01) );
	cbVGekuendigt->setChecked(false);
	leVNr->setText("");
	lbVBenutzer->clear();
	lbVRechnungen->clear();

	// Nchste freie Vertrags-Nummer finden
	QSqlQuery abfrage;
	abfrage.exec( "SELECT MAX(Vertrag.id)+1 FROM Vertrag;" );
	if ( abfrage.isActive() && abfrage.next() ) {
		leVNr->setText( abfrage.value(0).toString() );
	} else {
		leVNr->setText("");
	}
	
	kundenCombobox->setFocus();
	tbVertraege->refresh();
}


/**
 *	Vertrag wurde in Tabelle angeklickt
 */
void HauptFenster::vertrag_laden() {

    vertragsFormular->setRecord( vertragsCursor->primeUpdate() );
	vertragsFormular->readFields();
    
    QSqlQuery abfrage;
    
	// Benutzerlistbox neu erstellen:
	lbVBenutzer->clear();
	abfrage.exec( "SELECT  Benutzer.Name  FROM Benutzer WHERE Vertrag = '"+ leVNr->text() +"';" );
	if ( abfrage.isActive() ) {
		while ( abfrage.next() ) {
			lbVBenutzer->insertItem( abfrage.value(0).toString() , abfrage.at() );
		}
	}
	// Rechnungslistbox neu erstellen:
	lbVRechnungen->clear();
	abfrage.exec( "SELECT  Rechnung.id, Rechnung.Datum  FROM Rechnung WHERE Vertrag = '"+ leVNr->text() +"';" );
	if ( abfrage.isActive() ) {
		while ( abfrage.next() ) {
			lbVRechnungen->insertItem( abfrage.value(0).toString() +" vom "+ abfrage.value(1).toDate().toString(Qt::LocalDate) , abfrage.at() );
		}
	}
}



/**
 *	Vertrag speichern (Tab Vertrag -> Button Speichern)
 */
void HauptFenster::vertrag_speichern() {
	
	if ( leVNr->text() != vertragsCursor->primeUpdate()->field("id")->value().toString() ) {
	// Neuer Vertrag -> INSERT
    		vertragsFormular->setRecord( vertragsCursor->primeInsert() );
		vertragsFormular->writeFields();
		vertragsCursor->insert();
		tbVertraege->refresh();
		vertragsComboboxR->zuruecksetzen();
		vertragsComboboxB->zuruecksetzen();
	} else {	
	// Vorhandener Vertrag -> UPDATE
   		vertragsFormular->setRecord( vertragsCursor->primeUpdate() );
		vertragsFormular->writeFields();
    		vertragsCursor->update();
		tbVertraege->refresh();
		vertragsComboboxR->zuruecksetzen();
		vertragsComboboxB->zuruecksetzen();
	}
 }


/**
 *	Vertrag lschen (Tab Vertrag -> Button Lschen)
 */
void HauptFenster::vertrag_loeschen() {
	
	if ( leVNr->text() != "" ) {

		vertragsCursor->select( "id=" + leVNr->text() );
		if ( vertragsCursor->next() ) {

			GUI_Sicherheitsabfrage* loeschenDialog = new GUI_Sicherheitsabfrage();
			if ( loeschenDialog->exec() == QDialog::Accepted ) {

				// wirklich lschen
				vertragsCursor->primeDelete();
				vertragsCursor->del();
				vertragsComboboxR->zuruecksetzen();
				vertragsComboboxB->zuruecksetzen();
			}
			tbVertraege->refresh();
		} else {
			QMessageBox::information( this, "Vertrag lschen", "Vertrag nicht vorhanden!");
		}
	} else {
		QMessageBox::information( this, "Vertrag lschen", "Es wurde kein Vertrag ausgewhlt!");
	}
	vertrag_neu();
	vertragsCursor->select();
}


/**
 *	Vertrag suchen (Tab Vertrag -> Button Suchen)
 */
void HauptFenster::vertrag_suchen() {
	
	tbVertraege->setSort("");
	
	// Filter (=WHERE-Statement) setzen
	tbVertraege->setFilter( "Kunde LIKE '%"+  QString::number( kundenCombobox->kunde() ) +"%';" );
	
	// Ergebnis anzeigen
	tbVertraege->refresh();
	
	// Filter zurcksetzen - Anzeige aber erst bei nchstem refresh()
	tbVertraege->setFilter("");
}


/**
 *	Kunde anlegen (Tab Vertrag -> Button Kunde anlegen)
 */
void HauptFenster::vertrag_KundeNeu() {
	
	// Nur ausfhren, wenn Button nicht schon gedrckt ist
	if ( pbVKundeNeu->isOn() ) {
		kunde_neu();
		tabs->setCurrentPage(0);
	}	
}


/**
 *	Benutzer anlegen (Tab Vertrag -> Button Benutzer anlegen)
 */
void HauptFenster::vertrag_BenutzerNeu() {
	
	benutzer_neu();
	vertragsComboboxB->setVertrag( vertragsCursor->primeUpdate()->field("id")->value().toInt() );
	tabs->setCurrentPage(3);
}


/**
 *	Benutzer anlegen (Tab Vertrag -> Button Benutzer anlegen)
 */
void HauptFenster::vertrag_RechnungNeu() {
	
	rechnung_neu();
	vertragsComboboxR->setVertrag( vertragsCursor->primeUpdate()->field("id")->value().toInt() );
	tabs->setCurrentPage(2);
}


//////////////////////////////////////////////////////////////////////////////



/**
 *	Rechnungs-tabelle initialisieren
 */
void HauptFenster::rechnung_init() {

	// Abfrage-Cursor initialisieren und an Tabelle binden
	rechnungsCursor = new RechnungsCursor();
	tbRechnungen->setSqlCursor( rechnungsCursor, false, true );
	tbRechnungen->addColumn( "id", 			"Rechnung" );
	tbRechnungen->addColumn( "Datum", 		"Datum" );
	tbRechnungen->addColumn( "BetragNetto",	"EUR (Netto)" );
	tbRechnungen->addColumn( "bezahlt", 		"bezahlt" );
	tbRechnungen->addColumn( "bezahltAm", 	"bezahltAm" );
	tbRechnungen->addColumn( "Vertrag", 		"Vertrag" );
	tbRechnungen->addColumn( "_Kunde", 		"[gehrt zu Kunde]" );
	tbRechnungen->refresh();

	// Vertrags-ComboBox erstellen und in die GroupBox einfgen 
	// (berdecken der vom Designer erstellten ComboBox !)
	vertragsComboboxR = new VertragsCombobox( gbRechnungen, "VertragsComboboxR" );
	vertragsComboboxR->setGeometry( 70, 20, 335, 20 );
	
	// Eingabeformular einrichten
	rechnungsFormular = 	new QSqlForm( this );
    rechnungsFormular->setRecord( rechnungsCursor->primeUpdate() );
    rechnungsFormular->insert( leRNr, 		"id" );
    rechnungsFormular->insert( deRDatum, 	"Datum" );
    rechnungsFormular->insert( vertragsComboboxR,	"Vertrag" );
    rechnungsFormular->insert( leRBetrag, 	"BetragNetto" );
    rechnungsFormular->insert( cbRBezahlt, 	"bezahlt" );
    rechnungsFormular->insert( deRBezahlt, 	"bezahltAm" );

	// Spaltenbreiten anpassen
	for ( int spalte=0; spalte < tbRechnungen->numCols(); spalte++ ) {
		tbRechnungen->adjustColumn( spalte );
		tbRechnungen->setColumnWidth( spalte, tbRechnungen->columnWidth(spalte)+6 );
	}
	
	// Sortierung
	tbRechnungen->setSort( rechnungsCursor->index("id") );
	// Standard-Werte setzen
	vertrag_neu();
	rechnung_neu();
	
	rechnung_aktualisieren();
}


/**
 *	Neue Rechnung anlegen, Felder leeren (Tab Rechnung -> Button Neu)
 */
void HauptFenster::rechnung_neu() {

	vertragsComboboxR->setCurrentItem(0);
	leRNr->setText("");
	leRBetrag->setText("");
	deRDatum->setDate( QDate::currentDate() );
	cbRBezahlt->setChecked(false);
	deRBezahlt->setDate( QDate( 2000, 01, 01) );

	// Nchste freie Rechnungs-Nr ermittlen
	QSqlQuery abfrage;
	abfrage.exec( "SELECT  MAX(R.id)+1  FROM  Rechnung R;" );
	if ( abfrage.isActive() && abfrage.next() ) {
		leRNr->setText( abfrage.value(0).toString() );
	} else {
		leRNr->setText("1000");
	}

	vertragsComboboxR->setFocus();
	tbRechnungen->refresh();
}


/**
 *	Neue Rechnung anlegen -> klick in Listbox
 */
void HauptFenster::rechnung_neu(QListBoxItem* eintrag) {

	rechnung_neu();
	// finde erstes und zweites Leerzeichen; z.B.: "Vertrag 0815 blabla"
	int start = eintrag->text().find( " ", 0 );
	int ende  = eintrag->text().find( " ", start+1 );
	// Nimm Vertragsnummer zwischen den beiden Leerzeichen und setze Combobox entsprechend
	vertragsComboboxR->setVertrag( 
		QVariant::QVariant( eintrag->text().mid( start, ende-start ) ).toInt() 
	);
	// Rechnungsdatum standardmssig auf Datum der letzten Rechnung + 1 Jahr stellen
	QSqlQuery abfrage( 
		"SELECT DATE_ADD( MAX(R.Datum), INTERVAL 1 YEAR )  \
		 FROM   Vertrag V,Rechnung R  \
		 WHERE  R.Vertrag=V.id  AND  V.id='"+ eintrag->text().mid( start, ende-start ) +"' \
		 GROUP BY V.id;" 
	);
	if ( abfrage.isActive() && abfrage.next() ) {
		deRDatum->setDate( abfrage.value(0).toDate() );
	}
	deRDatum->setFocus();
}


/**
 *	Rechnung wurde in Tabelle angeklickt
 */
void HauptFenster::rechnung_laden() {
	
    rechnungsFormular->setRecord( rechnungsCursor->primeUpdate() );
    rechnungsFormular->readFields();
}


/**
 *	Rechnung speichern (Tab Rechnung -> Button Speichern)
 */
void HauptFenster::rechnung_speichern() {
	
	if ( leRNr->text() != rechnungsCursor->primeUpdate()->field("id")->value().toString() ) {
		// Neue Rechnung -> INSERT
    		rechnungsFormular->setRecord( rechnungsCursor->primeInsert() );
    		rechnungsFormular->writeFields();
		rechnungsCursor->insert();
		tbRechnungen->refresh();
	} else {
		// Rechnung ndern -> UPDATE
    		rechnungsFormular->setRecord( rechnungsCursor->primeUpdate() );
    		rechnungsFormular->writeFields();
    		rechnungsCursor->update();
		tbRechnungen->refresh();
	}	
}


/**
 *	Rechnung lschen (Tab Rechnung -> Button Lschen)
 */
void HauptFenster::rechnung_loeschen() {
	
	if ( leRNr->text() != "" ) {

		rechnungsCursor->select( "id='"+ leRNr->text() +"'" );
		if ( rechnungsCursor->next() ) {

			GUI_Sicherheitsabfrage* loeschenDialog = new GUI_Sicherheitsabfrage();
			if ( loeschenDialog->exec() == QDialog::Accepted ) {

				rechnungsCursor->primeDelete();
				rechnungsCursor->del();
				
			    qDebug("Rechnung: "+ leRNr->text() +" gelscht");
			}
		} else {
			QMessageBox::information( this, "Rechnung lschen", "Rechnung nicht vorhanden!");
		}
	} else {
		QMessageBox::information( this, "Rechnung lschen", "Es wurde keine Rechnung ausgewhlt!");
	}
	rechnung_neu();
	tbRechnungen->refresh();
}


/**
 *	Rechnung suchen (Tab Rechnung -> Button Suchen)
 */
void HauptFenster::rechnung_suchen() {
	
	tbRechnungen->setSort("");
	
	// Filter (-> WHERE-Statement) setzen
	tbRechnungen->setFilter(
		"Vertrag LIKE '%"+ QString::number( vertragsComboboxR->vertrag() ) +"%' AND " +
		"bezahlt = '"+ QVariant::QVariant( cbRBezahlt->isChecked() ).toString() +"';"
	);

	qDebug( QVariant::QVariant( cbRBezahlt->isChecked() ).toString() );

	// Ergebnis anzeigen
	tbRechnungen->refresh();
	
	// Filter zurcksetzen - Anzeige aber erst bei nchstem refresh()
	tbRechnungen->setFilter("");
}



/**
 *	Rechnungs-Listboxen aktualisieren - Liste aller Rechnungen generieren, die noch erstellt werden sollten
 */
void HauptFenster::rechnung_aktualisieren() {
	
	lbRzuErstellen->clear();	
	// Zeige alle Vertrge, die entweder noch gar keine,
	// oder zumindest im letzten Jahr keine Rechnung haben:
	QSqlQuery abfrage( 
		"SELECT V.id, V.Datum, K.Name, K.Vorname, MAX(R.Datum), COUNT(R.id)  \
		 FROM  Vertrag V, Kunde K, Rechnung R  \
		 WHERE (  \
		     V.Kunde=K.id  AND  R.Vertrag=V.id  AND  V.gekndigt=false  \
		     AND  NOT EXISTS ( SELECT * FROM Rechnung R WHERE  R.Vertrag=V.id AND Datum > '"+ QDate::currentDate().addYears(-1).toString(Qt::ISODate) +"'  )  \
		   )  \
		   OR  (  \
		     NOT EXISTS  ( SELECT * FROM Rechnung R WHERE  R.Vertrag=V.id  )  \
		     AND V.Kunde=K.id  AND  V.gekndigt=false \
		   )  \
		 GROUP BY V.id  ORDER BY V.id;" 	);
	if ( abfrage.isActive() ) {
		while ( abfrage.next() ) {
			lbRzuErstellen->insertItem( 	
				"V. " + abfrage.value(0).toString() + 
				" vom " + abfrage.value(1).toDate().toString(Qt::LocalDate) + 
				" (" + abfrage.value(2).toString() + ", " + abfrage.value(3).toString() + ") " +
				"letzte RE: " + abfrage.value(4).toDate().toString(Qt::LocalDate) + 
				" (" + abfrage.value(5).toString() + ".)" 
			);
		} 
	}
}



//////////////////////////////////////////////////////////////////////////////




/**
 *	Benutzer-tabelle initialisieren
 */
void HauptFenster::benutzer_init() {

	// Abfrage-Cursor initialisieren und an Tabelle binden
	benutzerCursor = new BenutzerCursor();
	tbBenutzer->setSqlCursor( benutzerCursor, false, true );
	tbBenutzer->addColumn( "Name", 	"Benutzername" );
	tbBenutzer->addColumn( "uid", 	"User-ID" );
	tbBenutzer->addColumn( "Speicher", "Speicher" );
	tbBenutzer->addColumn( "Passwort", "Passwort" );
	tbBenutzer->addColumn( "Mailbox", "Mailbox" );
	tbBenutzer->addColumn( "Domain", "Domain" );
	tbBenutzer->addColumn( "Datenbank", "Datenbank" );
	tbBenutzer->addColumn( "Vertrag", "Vertrag" );
	tbBenutzer->addColumn( "_Kunde", "[gehrt zu Kunde]" );
	tbBenutzer->refresh();
	
	// ComboBoxen erstellen und in die GroupBox einfgen 
	// (berdecken der vom Designer erstellten ComboBoxen !)
	vertragsComboboxB = new VertragsCombobox( gbBenutzer, "vertragsComboboxB" );
	vertragsComboboxB->setGeometry( 70, 20, 335, 20 );
	mailboxCombobox = new MailboxCombobox( gbBenutzer, "mailboxCombobox" );
	mailboxCombobox->setGeometry( 70, 95, 160, 20 );
	domainCombobox = new DomainCombobox( gbBenutzer, "domainCombobox" );
	domainCombobox->setGeometry( 70, 120, 160, 20 );
	datenbankCombobox = new DatenbankCombobox( gbBenutzer, "datenbankCombobox" );
	datenbankCombobox->setGeometry( 70, 145, 160, 20 );

	// Eingabeformular einrichten
	benutzerFormular = 	new QSqlForm( this );
	benutzerFormular->setRecord( benutzerCursor->primeUpdate() );
    benutzerFormular->insert( leBName, 		"Name" );
    benutzerFormular->insert( leBuid, 		"uid" );
    benutzerFormular->insert( leBPasswort, 	"Passwort" );
    benutzerFormular->insert( sbBSpeicher, 	"Speicher" );

    benutzerFormular->insert( vertragsComboboxB,	"Vertrag" );
    benutzerFormular->insert( mailboxCombobox,  	"Mailbox" );
    benutzerFormular->insert( domainCombobox,  	"Domain" );
    benutzerFormular->insert( datenbankCombobox,	"Datenbank" );

	// Spaltenbreiten anpassen
	for ( int spalte=0; spalte < tbBenutzer->numCols(); spalte++ ) {
		tbBenutzer->adjustColumn( spalte );
		tbBenutzer->setColumnWidth( spalte, tbBenutzer->columnWidth(spalte)+6 );
	}
	
	// Nchste freie UID automatisch eintragen
	benutzer_neu();
}



/**
 *	Neuen Benutzer anlegen, Felder leeren (Tab Benutzer -> Button Neu)
 */
void HauptFenster::benutzer_neu() {

	leBName->setText("");
	leBPasswort->setText("");
	sbBSpeicher->setValue( 100 );
	vertragsComboboxB->setCurrentItem(0);
	mailboxCombobox->setCurrentItem(0);
	domainCombobox->setCurrentItem(0);
	datenbankCombobox->setCurrentItem(0);

	// Nchste freie UID ermittlen
	QSqlQuery abfrage;
	abfrage.exec( "SELECT MAX(Benutzer.uid)+1 FROM Benutzer;" );
	if ( abfrage.isActive() && abfrage.next() ) {
		leBuid->setText( abfrage.value(0).toString() );
	} else {
		leBuid->setText("");
	}
	
	vertragsComboboxB->setFocus();
	tbBenutzer->refresh();
}


/**
 *	Benutzer wurde in Tabelle angeklickt
 */
void HauptFenster::benutzer_laden() {
	
    benutzerFormular->setRecord( benutzerCursor->primeUpdate() );
    benutzerFormular->readFields();
}


/**
 *	Benutzer speichern (Tab Benutzer -> Button Speichern)
 */
void HauptFenster::benutzer_speichern() {
	
	if ( leBName->text() != benutzerCursor->primeUpdate()->field("Name")->value().toString() ) {
		
		// Neuer Benutzer -> INSERT
    		benutzerFormular->setRecord( benutzerCursor->primeInsert() );
    		benutzerFormular->writeFields();
		benutzerCursor->insert();
		tbBenutzer->refresh();
	} else {
		// Benutzer ndern -> UPDATE
    		benutzerFormular->setRecord( benutzerCursor->primeUpdate() );
    		benutzerFormular->writeFields();
    		benutzerCursor->update();
		tbBenutzer->refresh();
	}	
}


/**
 *	Benutzer lschen (Tab Benutzer -> Button Lschen)
 */
void HauptFenster::benutzer_loeschen() {
	
	if ( leBName->text() != "" ) {

		benutzerCursor->select( "Name='"+ leBName->text() +"'" );
		if ( benutzerCursor->next() ) {

			GUI_Sicherheitsabfrage* loeschenDialog = new GUI_Sicherheitsabfrage();
			if ( loeschenDialog->exec() == QDialog::Accepted ) {

				benutzerCursor->primeDelete();
				benutzerCursor->del();
			    qDebug("Benutzer: "+ leBName->text() +" gelscht");
			}
		} else {
			QMessageBox::information( this, "Benutzer lschen", "Benutzer nicht vorhanden!");
		}
	} else {
		QMessageBox::information( this, "Benutzer lschen", "Es wurde kein Benutzer ausgewhlt!");
	}
	benutzer_neu();
	tbBenutzer->refresh();
}


/**
 *	Benutzer suchen (Tab Benutzer -> Button Suchen)
 */
void HauptFenster::benutzer_suchen() {
	
	tbBenutzer->setSort("");
	
	// Filter (-> WHERE-Statement) setzen
	tbBenutzer->setFilter(	"Name LIKE '%"+ leBName->text() +"%' ;"	);

	// Ergebnis anzeigen
	tbBenutzer->refresh();
	
	// Filter zurcksetzen - Anzeige aber erst bei nchstem refresh()
	tbBenutzer->setFilter("");
}


/**
 *	Mailbox anlegen -> (Tab Benutzer -> Button "Mailbox anlegen")
 */
void HauptFenster::benutzer_MailboxNeu() {
	
	// Nur ausfhren, wenn Button nicht schon gedrckt ist
	if ( pbBMailboxNeu->isOn() ) {
		mailbox_neu();
		leMName->setText( leBName->text() );
		leMAdresse->setText( "webmaster@" + leBName->text() );
		pbMSpeichern->setFocus();
		tabs->setCurrentPage(4);
	}
}


/**
 *	Domain anlegen -> (Tab Benutzer -> Button "Domain anlegen")
 */
void HauptFenster::benutzer_DomainNeu() {
	
	// Nur ausfhren, wenn Button nicht schon gedrckt ist
	if ( pbBDomainNeu->isOn() ) {
		domain_neu();
		leDName->setText( leBName->text() );
		pbDSpeichern->setFocus();
		tabs->setCurrentPage(5);
	}
}


/**
 *	Datenbank anlegen -> (Tab Benutzer -> Button "Datenbank anlegen")
 */
void HauptFenster::benutzer_DatenbankNeu() {
	
	// Nur ausfhren, wenn Button nicht schon gedrckt ist
	if ( pbBDatenbankNeu->isOn() ) {
		datenbank_neu();
		leDBName->setText( leBuid->text() );
		leDBPasswort->setFocus();
		tabs->setCurrentPage(6);
	}
}



//////////////////////////////////////////////////////////////////////////////



/**
 *	Mailbox-tabelle initialisieren
 */
void HauptFenster::mailbox_init() {

	// Abfrage-Cursor initialisieren und an Tabelle binden
	mailboxCursor = new MailboxCursor();
	tbMailboxen->setSqlCursor( mailboxCursor, false, true );
	tbMailboxen->addColumn( "Name", "Mailbox" );
	tbMailboxen->addColumn( "Adresse", "Adresse" );
	tbMailboxen->addColumn( "Speicher", "Speicher" );
	tbMailboxen->addColumn( "_UID", "[UID]" );
	tbMailboxen->refresh();
	
	// Eingabeformular einrichten
	mailboxFormular = new QSqlForm( this );	
	mailboxFormular->setRecord( mailboxCursor->primeUpdate() );
    mailboxFormular->insert( leMName, "Name" );
    mailboxFormular->insert( leMAdresse, "Adresse" );
    mailboxFormular->insert( sbMSpeicher, "Speicher" );
	
	// Spaltenbreiten anpassen
	for ( int spalte=0; spalte < tbMailboxen->numCols(); spalte++ ) {
		tbMailboxen->adjustColumn( spalte );
		tbMailboxen->setColumnWidth( spalte, tbMailboxen->columnWidth(spalte)+6 );

	}
}


/**
 *	Neue Mailbox anlegen, Felder leeren (Tab Mailbox -> Button Neu)
 */
void HauptFenster::mailbox_neu() {

	leMName->setText("");
	leMAdresse->setText("");
	sbMSpeicher->setValue( 100 );
	
	leMName->setFocus();
	tbMailboxen->refresh();
}


/**
 *	Mailbox wurde in Tabelle angeklickt
 */
void HauptFenster::mailbox_laden() {
	
	mailboxFormular->setRecord( mailboxCursor->primeUpdate() );
    mailboxFormular->readFields();
}


/**
 *	Mailbox speichern (Tab Mailbox -> Button Speichern)
 */
void HauptFenster::mailbox_speichern() {
	
	// Neue Mailbox -> INSERT
	if ( leMName->text() != mailboxCursor->primeUpdate()->field("Name")->value().toString() ) {
    		mailboxFormular->setRecord( mailboxCursor->primeInsert() );
    		mailboxFormular->writeFields();
		mailboxCursor->insert();
		tbMailboxen->refresh();
	// Mailbox ndern -> UPDATE
	} else {
    		mailboxFormular->setRecord( mailboxCursor->primeUpdate() );
    		mailboxFormular->writeFields();
    		mailboxCursor->update();
		tbMailboxen->refresh();
	}
	mailboxCombobox->zuruecksetzen();

	// Falls Mailbox ber Tab "Benutzer" -> Button "Mailbox anlegen" gespeichert wurde 
	// -> zurck zum "Mailbox"-Tab und Button zurcksetzen
	if ( pbBMailboxNeu->isOn() ) {
		tabs->setCurrentPage( 3 );
		mailboxCombobox->setMailbox( leMName->text() );
		pbBMailboxNeu->setOn( false );
	}
}


/**
 *	Mailbox lschen (Tab Mailbox -> Button Lschen)
 */
void HauptFenster::mailbox_loeschen() {
	
	if ( leMName->text() != "" ) {

		mailboxCursor->select( "Name='"+ leMName->text() +"'" );
		if ( mailboxCursor->next() ) {

			GUI_Sicherheitsabfrage* loeschenDialog = new GUI_Sicherheitsabfrage();
			if ( loeschenDialog->exec() == QDialog::Accepted ) {

				mailboxCursor->primeDelete();
				mailboxCursor->del();
				
			    qDebug("Mailbox: "+ leMName->text() +" gelscht");
			}
		} else {
			QMessageBox::information( this, "Mailbox lschen", "Mailbox nicht vorhanden!");
		}
	} else {
		QMessageBox::information( this, "Mailbox lschen", "Es wurde keine Mailbox ausgewhlt!");
	}
	mailboxCombobox->zuruecksetzen();
	mailbox_neu();
	tbMailboxen->refresh();
}


/**
 *	Mailbox suchen (Tab Mailbox -> Button Suchen)
 */
void HauptFenster::mailbox_suchen() {
	
	tbMailboxen->setSort("");
	
	// Filter (-> WHERE-Statement) setzen
	tbMailboxen->setFilter(	"Name LIKE '%"+ leMName->text() +"%' AND "+
							"Adresse LIKE '%"+ leMAdresse->text() +"%' ;" );

	// Ergebnis anzeigen
	tbMailboxen->refresh();
	
	// Filter zurcksetzen - Anzeige aber erst bei nchstem refresh()
	tbMailboxen->setFilter("");
}




//////////////////////////////////////////////////////////////////////////////



/**
 *	Domain-tabelle initialisieren
 */
void HauptFenster::domain_init() {

	// Abfrage-Cursor initialisieren, an Tabelle binden und Spalten anzeigen
	domainCursor = new DomainCursor();
	tbDomains->setSqlCursor( domainCursor, false, true );
	tbDomains->addColumn( "Name", "Domain" );
	tbDomains->addColumn( "_UID", "[UID]" );
	tbDomains->addColumn( "hatMailinglisten", "hat ML" );
	tbDomains->refresh();
	
	// Eingabeformular einrichten
	domainFormular = new QSqlForm( this );
    domainFormular->setRecord( domainCursor->primeUpdate() );
    domainFormular->insert( leDName, "Name" );
    domainFormular->insert( cbDMailinglisten, "hatMailinglisten" );

	// Spaltenbreiten anpassen
	for ( int spalte=0; spalte < tbDomains->numCols(); spalte++ ) {
		tbDomains->adjustColumn( spalte );
		tbDomains->setColumnWidth( spalte, tbDomains->columnWidth(spalte)+6 );

	}
}


/**
 *	Neue Domain anlegen, Felder leeren (Tab Domain -> Button Neu)
 */
void HauptFenster::domain_neu() {

	leDName->setText("");
	cbDMailinglisten->setChecked( false );
	
	leDName->setFocus();
	tbDomains->refresh();
}


/**
 *	Domain wurde in Tabelle angeklickt
 */
void HauptFenster::domain_laden() {
	
    domainFormular->setRecord( domainCursor->primeUpdate() );
    domainFormular->readFields();
}


/**
 *	Domain speichern (Tab Domain -> Button Speichern)
 */
void HauptFenster::domain_speichern() {
	
	// Neue Domain -> INSERT
	if ( leDName->text() != domainCursor->primeUpdate()->field("Name")->value().toString() ) {
 		domainFormular->setRecord( domainCursor->primeInsert() );
 		domainFormular->writeFields();
		domainCursor->insert();
		tbDomains->refresh();
	// Domain ndern -> UPDATE
	} else {
    		domainFormular->setRecord( domainCursor->primeUpdate() );
    		domainFormular->writeFields();
    		domainCursor->update();
		tbDomains->refresh();
	}
	domainCombobox->zuruecksetzen();

	// Falls Domain ber Tab "Benutzer" -> Button "Domain anlegen" gespeichert wurde 
	// -> zurck zum "Benutzer"-Tab und Button zurcksetzen
	if ( pbBDomainNeu->isOn() ) {
		domainCombobox->setDomain( leDName->text() );
		tabs->setCurrentPage( 3 );
		pbBDomainNeu->setOn( false );
	}
}


/**
 *	Domain lschen (Tab Domain -> Button Lschen)
 */
void HauptFenster::domain_loeschen() {
	
	if ( leDName->text() != "" ) {

		domainCursor->select( "Name='"+ leDName->text() +"'" );
		if ( domainCursor->next() ) {

			GUI_Sicherheitsabfrage* loeschenDialog = new GUI_Sicherheitsabfrage();
			if ( loeschenDialog->exec() == QDialog::Accepted ) {

				domainCursor->primeDelete();
				domainCursor->del();
			    qDebug("Domain: "+ leDName->text() +" gelscht");
			}
		} else {
			QMessageBox::information( this, "Domain lschen", "Domain nicht vorhanden!");
		}
	} else {
		QMessageBox::information( this, "Domain lschen", "Es wurde keine Domain ausgewhlt!");
	}
	domainCombobox->zuruecksetzen();
	domain_neu();
	tbDomains->refresh();
}


/**
 *	Domain suchen (Tab Domain -> Button Suchen)
 */
void HauptFenster::domain_suchen() {

	tbDomains->setSort("");

	// Filter (-> WHERE-Statement) setzen
	tbDomains->setFilter( "Name LIKE '%"+ leDName->text() +"%';" );

	// Ergebnis anzeigen
	tbDomains->refresh();
	
	// Filter zurcksetzen - Anzeige aber erst bei nchstem refresh()
	tbDomains->setFilter("");
}



//////////////////////////////////////////////////////////////////////////////



/**
 *	Datenbanken-tabelle initialisieren
 */
void HauptFenster::datenbank_init() {

	// Abfrage-Cursor initialisieren und an Tabelle binden
	datenbankCursor = new DatenbankCursor();
	tbDatenbanken->setSqlCursor( datenbankCursor, false, true );
	tbDatenbanken->addColumn( "Name", "DB-Name" );
	tbDatenbanken->addColumn( "Passwort", "Passwort" );
	tbDatenbanken->addColumn( "Speicher", "Speicher" );
	tbDatenbanken->addColumn( "_UID", "[UID]" );		
	tbDatenbanken->refresh();
	
	// Eingabeformular einrichten
	datenbankFormular = 	new QSqlForm( this );
    datenbankFormular->setRecord( datenbankCursor->primeUpdate() );
    datenbankFormular->insert( leDBName, "Name" );
    datenbankFormular->insert( leDBPasswort, "Passwort" );
    datenbankFormular->insert( sbDBSpeicher, "Speicher" );

	// Spaltenbreiten anpassen
	for ( int spalte=0; spalte < tbDatenbanken->numCols(); spalte++ ) {
		tbDatenbanken->adjustColumn( spalte );
		tbDatenbanken->setColumnWidth( spalte, tbDatenbanken->columnWidth(spalte)+6 );
	}
}


/**
 *	Neue Datenbank anlegen, Felder leeren (Tab Datenbank -> Button Neu)
 */
void HauptFenster::datenbank_neu() {

	leDBName->setText("");
	leDBPasswort->setText("");
	sbDBSpeicher->setValue( 10 );
	
	leDBName->setFocus();
	tbDatenbanken->refresh();
}


/**
 *	DB wurde in Tabelle angeklickt
 */
void HauptFenster::datenbank_laden() {
	
    datenbankFormular->setRecord( datenbankCursor->primeUpdate() );
    datenbankFormular->readFields();
}


/**
 *	Datenbank speichern (Tab Datenbank -> Button Speichern)
 */
void HauptFenster::datenbank_speichern() {
	
	// Neue Datenbank -> INSERT
	if ( leDBName->text() != datenbankCursor->primeUpdate()->field("Name")->value().toString() ) {
	    datenbankFormular->setRecord( datenbankCursor->primeInsert() );
		datenbankFormular->writeFields();
		datenbankCursor->insert();
		tbDatenbanken->refresh();
	// Datenbank ndern -> UPDATE
	} else {
    		datenbankFormular->setRecord( datenbankCursor->primeUpdate() );
    		datenbankFormular->writeFields();
    		datenbankCursor->update();
		tbDatenbanken->refresh();
	}	
	datenbankCombobox->zuruecksetzen();

	// Falls DB ber Tab "Benutzer" -> Button "DB anlegen" gespeichert wurde 
	// -> zurck zum "Datenbanken"-Tab und Button zurcksetzen
	if ( pbBDatenbankNeu->isOn() ) {
		datenbankCombobox->setDatenbank( leDBName->text() );
		tabs->setCurrentPage( 3 );
		pbBDatenbankNeu->setOn( false );
	}
}


/**
 *	Datenbank lschen (Tab Datenbank -> Button Lschen)
 */
void HauptFenster::datenbank_loeschen() {
	
	if ( leDBName->text() != "" ) {

		datenbankCursor->select( "Name='"+ leDBName->text() +"'" );
		if ( datenbankCursor->next() ) {

			GUI_Sicherheitsabfrage* loeschenDialog = new GUI_Sicherheitsabfrage();
			if ( loeschenDialog->exec() == QDialog::Accepted ) {

				datenbankCursor->primeDelete();
				datenbankCursor->del();
			    qDebug("Datenbank: "+ leDBName->text() +" gelscht");
			}
		} else {
			QMessageBox::information( this, "Datenbank lschen", "Datenbank nicht vorhanden!");
		}
	} else {
		QMessageBox::information( this, "Datenbank lschen", "Es wurde keine Datenbank ausgewhlt!");
	}
	datenbankCombobox->zuruecksetzen();
	datenbank_neu();
	tbDatenbanken->refresh();
}


/**
 *	Datenbank suchen (Tab Datenbank -> Button Suchen)
 */
void HauptFenster::datenbank_suchen() {
	
	tbDatenbanken->setSort("");
	
	// Filter (-> WHERE-Statement) setzen
	tbDatenbanken->setFilter( 	"Name LIKE '%"+ leDBName->text() +"%';" );

	// Ergebnis anzeigen
	tbDatenbanken->refresh();
	
	// Filter zurcksetzen - Anzeige aber erst bei nchstem refresh()
	tbDatenbanken->setFilter("");
}



//////////////////////////////////////////////////////////////////////////////



/**
 *	Info-Meldung (Men -> Hilfe -> Info)
 */
void HauptFenster::menu_hilfe_info() {
	QMessageBox::information( this, "Informationen zu diesem Programm",
	                          "Projektarbeit zur Vorlesung Datenbanken von Prof. Dr. Zhou<br><br>\
	                          <b>Kundenverwaltungsystem fr ein Webhosting-Unternehmen</b><br><br>\
	                          NTA FH Isny, WS 2005/2006<br> David Mayr, 12.Info<br>"
	                        );
}


/**
 *	Info-Meldung (Men -> Hilfe -> Info)
 */
void HauptFenster::menu_extras_mailingliste() {

	// eMail-Liste generieren..
	QString mailingliste;
	QString filter;
	kundenCursor->filter() == "" ? filter="1=1" : filter=kundenCursor->filter();
	QSqlQuery abfrage;
	abfrage.exec( "SELECT  eMail  FROM  Kunde  WHERE  "+ filter +";" );
	if ( abfrage.isActive() ) {
		while ( abfrage.next() ) {
			// Listbox fllen
			if ( abfrage.value(0).toString() != "" ) {
				mailingliste += abfrage.value(0).toString() + ", ";
			}
		}
	}
	// ... und anzeigen
	mailinglistenDialog = new GUI_Mailingliste();
	mailinglistenDialog->te_mailingliste->setText( mailingliste );
	mailinglistenDialog->show();
}


/**
 *	Datenbank-Verbindung konfigurieren (Men -> Einstellungen -> DB-Verb.)
 */
void HauptFenster::menu_einstellungen_datenbank() {

	konfiguration->move( 	pos().x() + width()/2 - konfiguration->width()/2 , 
							pos().y() + height()/2 - konfiguration->height()/2 );
	konfiguration->show();
}


